<?php
/**
 * Manages Perfect Checkout dashboard assets.
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Admin
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Perfect_Checkout_Admin_Assets' ) ) {

	class Perfect_Checkout_Admin_Assets {

		/**
		 * Constructor
		 *
		 * @access public
		 */
		public function __construct() {
			add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );

			// Adds admin body classes.
			add_filter( 'admin_body_class', array( $this, 'admin_body_class' ) );
		} // END __construct()

		/**
		 * Registers and enqueue Stylesheets and Scripts.
		 *
		 * @access public
		 */
		public function enqueue_scripts() {
			$screen    = get_current_screen();
			$screen_id = $screen ? $screen->id : '';
			$suffix    = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

			if ( in_array( $screen_id, Perfect_Checkout_Helpers::perfect_checkout_get_admin_screens() ) ) {
				wp_register_style( 'perfectcheckout_admin', untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/css/admin/perfect-checkout' . $suffix . '.css', array(), PerfectCheckout::$version );
				wp_enqueue_style( 'perfectcheckout_admin' );

				wp_register_script( 'perfectcheckout_admin', untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/js/admin/perfectcheckout_admin' . $suffix . '.js', array( 'jquery', 'jquery-tiptip' ), PerfectCheckout::$version, true );
				wp_enqueue_script( 'perfectcheckout_admin' );
			}

			if ( in_array( 'plugins', Perfect_Checkout_Helpers::perfect_checkout_get_admin_screens() ) ) {
				wp_register_style( 'perfectcheckout_modal', untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/css/admin/modal' . $suffix . '.css', array(), PerfectCheckout::$version );
				wp_enqueue_style( 'perfectcheckout_modal' );
				wp_register_script( 'perfectcheckout_modal', untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/js/admin/modal' . $suffix . '.js', array( 'jquery' ), PerfectCheckout::$version, true );
				wp_enqueue_script( 'perfectcheckout_modal' );
			}
		} // END enqueue_scripts()

		/**
		 * Adds admin body class for Perfect Checkout page.
		 *
		 * @access public
		 * @param  string $classes - Classes added before.
		 * @return string $classes - Classes returned after.
		 */
		public function admin_body_class( $classes ) {
			$screen    = get_current_screen();
			$screen_id = $screen ? $screen->id : '';

			if ( 'toplevel_page_perfect-checkout' === $screen_id ) {
				$classes = ' perfect-checkout ';
			}

			return $classes;
		} // END admin_body_class()

	} // END class

} // END if class exists

return new Perfect_Checkout_Admin_Assets();
