<?php
/**
 * Perfect Checkout Settings
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Admin\Settings
 * @since   1.0.0
 * @version 1.2.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Perfect_Checkout_Settings' ) ) {

	class Perfect_Checkout_Settings extends Perfect_Checkout_Settings_Page {

		/**
		 * Constructor.
		 *
		 * @access  public
		 */
		public function __construct() {
			$this->id    = 'general';
			$this->label = esc_html__( 'Perfect Checkout', 'perfect-checkout' );

			parent::__construct();
		} // END __construct()

		/**
		 * Get settings array.
		 *
		 * @access public
		 * @return array
		 */
		public function get_settings() {
			$settings = array();

			$settings[] = array(
				// 'title' => esc_html__( 'Licence Key', 'perfect-checkout' ),
				'type' => 'title',
				// 'desc' => esc_html__( 'Enter your Perfect Checkout API key', 'perfect-checkout' ),
				'id'   => 'licence_key',
			);

			$settings[] = array(
				'title'    => esc_html__( 'License Key', 'perfect-checkout' ),
				'id'       => 'perfectcheckout_license',
				'type'     => 'text',
				'default'  => '',
				'css'      => 'min-width:340px;',
				'class'    => 'required',
				'desc'     => sprintf( __( 'Important: Make sure the “connected store” in your %1$sPerfect Dashboard%2$s matches the site this plugin is activated on. Your license is good for 1 connected store at a time.', 'perfect-checkout' ), '<a href="' . esc_url( 'https://my.perfectcheckout.com/user/login' ) . '" target="_blank">', '</a>' ),
				'autoload' => false,
			);

			$settings[] = array(
				'type' => 'sectionend',
				'id'   => 'licence_key',
			);

			$settings[] = array(
				'title' => esc_html__( 'Google Analytics', 'perfect-checkout' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Enter your Google Analytics tracking ID so Perfect Checkout can help you track customers actions.', 'perfect-checkout' ),
				'id'    => 'google_analytics',
			);

			$settings[] = array(
				// 'title'    => esc_html__( 'Google Analytics Tracking ID', 'perfect-checkout' ),
				'id'          => 'perfectcheckout_google_analytics',
				'type'        => 'text',
				'default'     => '',
				'css'         => 'width:100%;',
				'desc'        => esc_html__( 'This can be found in your Google Analytics account settings.', 'perfect-checkout' ),
				'placeholder' => 'G-QN6BTJ6W0S',
				'autoload'    => false,
			);

			$settings[] = array(
				'type' => 'sectionend',
				'id'   => 'google_analytics',
			);

			$settings[] = array(
				'title' => esc_html__( 'Checkout Now', 'perfect-checkout' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Let your customers checkout instantly by enabling our checkout now buttons.', 'perfect-checkout' ),
				'id'    => 'checkout_now',
			);

			$settings[] = array(
				'title'   => '',
				'desc'    => __( 'Enable "Checkout Now" buttons on shop page.', 'perfect-checkout' ),
				'id'      => 'perfectcheckout_shop_checkout_button',
				'default' => 'no',
				'type'    => 'checkbox',
			);

			$settings[] = array(
				'title'   => '',
				'desc'    => __( 'Enable "Checkout Now" button on product pages.', 'perfect-checkout' ),
				'id'      => 'perfectcheckout_checkout_button',
				'default' => 'no',
				'type'    => 'checkbox',
			);

			$settings[] = array(
				'type' => 'sectionend',
				'id'   => 'checkout_now',
			);

			return $settings;
		} // END get_settings()

		/**
		 * Output the settings.
		 *
		 * @access public
		 */
		public function output() {
			$settings = $this->get_settings();

			Perfect_Checkout_Admin_Settings::output_fields( $settings );
		} // END output()

		/**
		 * Save settings.
		 *
		 * @access public
		 */
		public function save() {
			$settings = $this->get_settings();

			Perfect_Checkout_Admin_Settings::save_fields( $settings );
		} // END save()

	} // END class

} // END if class exists

return new Perfect_Checkout_Settings();
