<?php
/**
 * Perfect Checkout Page Functions
 *
 * Functions related to pages.
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Functions
 * @since   1.0.2
 * @version 1.2.0
 * @license GPL-2.0+
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'is_perfect_checkout' ) ) {
	/**
	 * Returns true when viewing the PerfectCheckout page.
	 *
	 * @return bool
	 */
	function is_perfect_checkout() {
		$page_id = get_option( 'perfectcheckout_page_id' );

		return ( $page_id && is_page( $page_id ) );
	}
}

/**
 * Gets the url to the perfect checkout page.
 *
 * @since  1.2.0
 * @return string Url to perfect checkout page
 */
if ( ! function_exists( 'pc_get_checkout_url' ) ) {
	function pc_get_checkout_url() {
		$checkout_url = wc_get_page_permalink( 'cart' );

		if ( $checkout_url ) {
			// Force SSL if needed.
			if ( is_ssl() || 'yes' === get_option( 'woocommerce_force_ssl_checkout' ) ) {
				$checkout_url = str_replace( 'http:', 'https:', $checkout_url );
			}
		}

		return $checkout_url;
	}
}
